@@ -68,6 +68,6 @@ sunone_send_to (CamelTransport *transport, CamelMimeMessage *message,
 		  CamelException *ex)
 {
 	camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
-		_("Send operation is not supported by Sun WCAP protocal"));
+		_("Send operation is not supported by Sun WCAP protocol"));
 	return FALSE;
 }
